package com.ruoyi.zongzhi.service;

import java.util.List;
import com.ruoyi.zongzhi.domain.TcAttack;

/**
 * 地区受攻击Service接口
 * 
 * @author ruoyi
 * @date 2023-08-21
 */
public interface ITcAttackService 
{
    /**
     * 查询地区受攻击
     * 
     * @param id 地区受攻击主键
     * @return 地区受攻击
     */
    public TcAttack selectTcAttackById(Long id);

    /**
     * 查询地区受攻击列表
     * 
     * @param tcAttack 地区受攻击
     * @return 地区受攻击集合
     */
    public List<TcAttack> selectTcAttackList(TcAttack tcAttack);

    /**
     * 新增地区受攻击
     * 
     * @param tcAttack 地区受攻击
     * @return 结果
     */
    public int insertTcAttack(TcAttack tcAttack);

    /**
     * 修改地区受攻击
     * 
     * @param tcAttack 地区受攻击
     * @return 结果
     */
    public int updateTcAttack(TcAttack tcAttack);

    /**
     * 批量删除地区受攻击
     * 
     * @param ids 需要删除的地区受攻击主键集合
     * @return 结果
     */
    public int deleteTcAttackByIds(Long[] ids);

    /**
     * 删除地区受攻击信息
     * 
     * @param id 地区受攻击主键
     * @return 结果
     */
    public int deleteTcAttackById(Long id);
}
